@@ -223,6 +223,7 @@ class FPLAnalytics:
         players['assist_diff90'] = players['assists90'] - players['xA90']
         players['pg90'] = players['goals_scored90'] - players['npg90']
         players['pgxG90'] = players['xG90'] - players['npxG90']
+        players['vapm'] = players['points_per_game'].astype(float) * 10 /players['now_cost'].astype(float)
 
         return players
 
@@ -388,8 +389,7 @@ class FPLAnalytics:
                         'xGBuildup90',
                         'shots90', 
                         'key_passes90',
-                        'goals_diff90', 
-                        'assist_diff90',
+                        'vapm',
                         'bps90']
 
         try:
@@ -447,3 +447,4 @@ class FPLAnalytics:
                 plt.close(fig)
         
         return players
+
