@@ -6,6 +6,7 @@ import json
 import aiohttp
 from bs4 import BeautifulSoup
 import pandas as pd
+import threading
 
 NAME_LOOKUP = {
     'Rui Patrício': 'Rui Pedro dos Santos Patrício',
@@ -489,5 +490,11 @@ class GetStats:
     
     def get_league_players(self, league_name = 'epl', season = '2020'):
         
-        loop = asyncio.get_event_loop()
-        loop.run_until_complete(self.async_get_league_player(league_name, season))
+        #loop = asyncio.get_event_loop()
+        #loop.create_task(self.async_get_league_player(league_name, season))
+        t1 = threading.Thread(target=asyncio.run, args=(self.async_get_league_player(league_name, season), ))
+        t1.start()
+        t1.join()
+        #asyncio.run_coroutine_threadsafe(self.async_get_league_player(league_name, season), loop)
+        
+
